@@ -351,7 +351,7 @@ def check_credentials(config):
 
 
 def prepare(**kwargs):
-    if not is_github():
+    if not fromenv.is_github():
         check_env_vars(**kwargs)
     config = get_config(**kwargs)
     check_credentials(config)
